@@ -117,7 +117,7 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
 
     private HttpUriRequest createRequest() {
         String clientId = "open-xchange-mobile-api-facade";
-        if (credentials.getClientId() != null) {
+        if (!StringUtils.isEmpty(credentials.getClientId())) {
             clientId += "-" + credentials.getClientId();
         }
         RequestBuilder builder = RequestBuilder.post(createUrl());
