@@ -152,7 +152,7 @@ public class HostConfiguration {
         loadMinimumVersions(configurationService);
         threadingType = ThreadingType.from(ConfigurationHelper.getString(configurationService, THREADING_TYPE, ThreadingType.THREADREFERENCES.toString()));
         numMailsPerFolder = ConfigurationHelper.getNumberString(configurationService, MAILS_PER_FOLDER, "10000");
-        returnNonPrimaryAccounts = ConfigurationHelper.getBoolean(configurationService, RETURN_NON_PRIMARY_ACCOUNTS, true);
+        returnNonPrimaryAccounts = ConfigurationHelper.getBoolean(configurationService, RETURN_NON_PRIMARY_ACCOUNTS, false);
         includeNonPrivateFolders = ConfigurationHelper.getBoolean(configurationService, INCLUDE_NON_PRIVATE_FOLDERS, false);
         mailTeasersEnabled = ConfigurationHelper.getBoolean(configurationService, MAIL_TEASERS_ENABLED, true);
         mailTeasersDefaultLength = ConfigurationHelper.getNumber(configurationService, MAIL_TEASERS_DEFAULT_LENGTH, 300);
@@ -183,6 +183,13 @@ public class HostConfiguration {
             String propertyName = entry.getKey();
             Object propertyValue = entry.getValue();
             String minimalVersionValue;
+            String platformName = getPlatformForBrandedMinimumClientVersionProperty(propertyName);
+            if (platformName != null) {
+                minimalVersionValue = getString(propertyValue, null);
+                if (minimalVersionValue != null) {
+                    minimumClientVersions.put(platformName, minimalVersionValue);
+                }
+            }
             switch (propertyName) {
             case THREADING_TYPE:
                 threadingType = ThreadingType.from(getString(propertyValue, ThreadingType.THREADREFERENCES.toString()));
@@ -236,6 +243,25 @@ public class HostConfiguration {
         }
     }
 
+    private String getPlatformForBrandedMinimumClientVersionProperty(String propertyName) {
+        String platformName = null;
+        if (propertyName.startsWith(MINIMUM_CLIENT_VERSION_ANDROID)) {
+            platformName = getPlatformForBrandedMinimumClientVersionProperty(propertyName, MINIMUM_CLIENT_VERSION_ANDROID, PLATFORM_ANDROID);
+        } else if (propertyName.startsWith(MINIMUM_CLIENT_VERSION_IOS)) {
+            platformName = getPlatformForBrandedMinimumClientVersionProperty(propertyName, MINIMUM_CLIENT_VERSION_IOS, PLATFORM_IOS);
+        } else if (propertyName.startsWith(MINIMUM_CLIENT_VERSION_WINDOWS)) {
+            platformName = getPlatformForBrandedMinimumClientVersionProperty(propertyName, MINIMUM_CLIENT_VERSION_WINDOWS, PLATFORM_WINDOWS);
+        }
+        return platformName;
+    }
+
+    private String getPlatformForBrandedMinimumClientVersionProperty(String propertyName, String platformPropertyName, String platformName) {
+        if (propertyName.length() > platformPropertyName.length() + 1) {
+            platformName += "." + propertyName.substring(platformPropertyName.length() + 1);
+        }
+        return platformName;
+    }
+
     private String getString(Object value, String defaultValue) {
         if (value instanceof String) {
             return (String) value;
