@@ -77,6 +77,8 @@ public class ApiFacadeException extends WebApplicationException {
 
         int MAXIMUM_NUMBER_OF_SESSIONS_EXCEEDED = 6;
 
+        int ACCOUNT_NOT_FOUND = 7;
+
         String INVALID_SESSION = "SES-206";
 
         int CLIENT_UPDATE_MANDATORY = 900;
@@ -185,8 +187,12 @@ public class ApiFacadeException extends WebApplicationException {
         return new ApiFacadeException(errorCode, cause, message, response);
     }
 
-    public static Exception weakforceInvalidHashAlgorithm(String algorithm) {
+    public static ApiFacadeException weakforceInvalidHashAlgorithm(String algorithm) {
         return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, "Hashing algorithm not supported: " + algorithm);
     }
 
+    public static ApiFacadeException accountNotFound(String accountId) {
+        return create(Status.NOT_FOUND, Code.ACCOUNT_NOT_FOUND, "Account not found: " + accountId);
+    }
+
 }
