@@ -58,6 +58,7 @@ import com.openexchange.mobile.api.facade.auth.impl.DefaultAuthenticationService
 import com.openexchange.mobile.api.facade.configuration.ConfigurationHelper;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
 import com.openexchange.mobile.api.facade.connectors.impl.DefaultConnectorFactoryFactory;
+import com.openexchange.mobile.api.facade.endpoints.AccountsEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.AuthenticationEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.ConfigEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.ContactsEndpoint;
@@ -68,6 +69,7 @@ import com.openexchange.mobile.api.facade.endpoints.PushEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.UsersEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.VersionEndpoint;
 import com.openexchange.mobile.api.facade.exceptions.UnhandledExceptionMapper;
+import com.openexchange.mobile.api.facade.services.AccountsService;
 import com.openexchange.mobile.api.facade.services.ConfigService;
 import com.openexchange.mobile.api.facade.services.ContactsService;
 import com.openexchange.mobile.api.facade.services.FoldersService;
@@ -132,12 +134,13 @@ public class Activator extends HousekeepingActivator implements Reloadable {
         FoldersService foldersService = new FoldersService(connectorFactoryFactory);
         registerService(FoldersEndpoint.class, new FoldersEndpoint(foldersService));
 
+        AccountsService accountsService = new AccountsService(connectorFactoryFactory, foldersService);
+        foldersService.setAccountsService(accountsService);
+        registerService(AccountsEndpoint.class, new AccountsEndpoint(accountsService));
+
         MailsService mailsService = new MailsService(connectorFactoryFactory);
         registerService(MailsEndpoint.class, new MailsEndpoint(mailsService));
 
-        ManifestService manifestService = new ManifestService(connectorFactoryFactory);
-        registerService(ManifestEndpoint.class, new ManifestEndpoint(manifestService));
-
         PushService pushService = new PushService(connectorFactoryFactory);
         registerService(PushEndpoint.class, new PushEndpoint(pushService));
 
@@ -147,6 +150,9 @@ public class Activator extends HousekeepingActivator implements Reloadable {
         VersionService versionService = new VersionService(connectorFactoryFactory);
         registerService(VersionEndpoint.class, new VersionEndpoint(versionService));
 
+        ManifestService manifestService = new ManifestService(connectorFactoryFactory, versionService);
+        registerService(ManifestEndpoint.class, new ManifestEndpoint(manifestService));
+
         registerService(Reloadable.class, this);
 
         openTrackers();
