@@ -111,7 +111,7 @@ public class RequestUtil {
 
     private static final int USER_AGENT_MAXLEN = 100;
 
-    private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^.*\\.(.*)\\.Mail/(\\S*) \\(.*\\)$");
+    private static final Pattern USER_AGENT_PATTERN = Pattern.compile("^(.*)\\.(.*)\\.Mail/(\\S*) \\(.*\\)$");
 
     @SneakyThrows
     public RequestConfiguration createConfiguration() {
@@ -175,7 +175,7 @@ public class RequestUtil {
 
     public boolean minimumClientVersionSatisfied(UserAgentInfo userAgentInfo, Map<String, String> minimumClientVersions) {
         String clientVersionStr = userAgentInfo.getVersion();
-        String minimumClientVersionStr = minimumClientVersions.get(userAgentInfo.getPlatform());
+        String minimumClientVersionStr = getMinimumClientVersion(minimumClientVersions, userAgentInfo);
         if (StringUtils.isEmpty(minimumClientVersionStr)) {
             return true;
         }
@@ -187,6 +187,15 @@ public class RequestUtil {
         return !clientVersion.isLowerThan(minimumClientVersion);
     }
 
+    private String getMinimumClientVersion(Map<String, String> minimumClientVersions, UserAgentInfo userAgentInfo) {
+        String platform = userAgentInfo.getPlatform();
+        String minimumClientVersion = minimumClientVersions.get(platform + "." + userAgentInfo.getBrand());
+        if (minimumClientVersion == null) {
+            minimumClientVersion = minimumClientVersions.get(platform);
+        }
+        return minimumClientVersion;
+    }
+
     @SneakyThrows
     private List<Cookie> getCookies(HttpServletRequest request, String targetDomain) {
         javax.servlet.http.Cookie[] cookies = request.getCookies();
@@ -238,12 +247,13 @@ public class RequestUtil {
         if (!matcher.find()) {
             throw ApiFacadeException.invalidUserAgent();
         }
-        if (matcher.groupCount() != 2) {
+        if (matcher.groupCount() != 3) {
             throw ApiFacadeException.invalidUserAgent();
         }
-        String platform = matcher.group(1);
-        String clientVersion = matcher.group(2);
-        return new UserAgentInfo(platform, clientVersion);
+        String brand = matcher.group(1);
+        String platform = matcher.group(2);
+        String clientVersion = matcher.group(3);
+        return new UserAgentInfo(brand, platform, clientVersion);
     }
 
     /*private*/ String getIfNoneMatch(HttpServletRequest request) {
